#ifndef NT2_INCLUDE_CONSTANTS_SEVEN_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SEVEN_HPP_INCLUDED

#include <nt2/constant/include/constants/seven.hpp>

#endif
